==> 0.0.2.tar.gz: lib/models/location.dart <==
part of navigine_api;

class Location {
  int id = 0, sort = 0, userRoleId = 0, userPermissionId = 0;
  String title;
  String description = "";
  bool isPublic = false, activeDragDrop = false, state = false;
  List<SubLocation> subLocations;

  static Location fromMap(var data) {
    return Location()
      ..id = data["id"]
      ..sort = data["sort"]
      // ..state = data["state"]
      ..userRoleId = data["userRoleId"]
      ..userPermissionId = data["userPermissionId"]
      ..title = data["title"]
      ..description = data["description"]
      ..isPublic = data["is_public"]
      ..activeDragDrop = data["active_drag_drop"]
      ..subLocations = (data["sub_locations"] ?? [])
          .map<SubLocation>((l) => SubLocation.fromMap(l))
          .toList();
  }

  SubLocation getSubLocationDetail(int id) {
    return subLocations.firstWhere((sl) => sl.id == id);
  }

  Future<void> saveLocation() async {
    await _httpHelper.getRequest("/versions/save", body: {
      "format": "json",
      "locationId": id.toString(),
    });
  }

  Future addNewSubLocation(
    String title,
    File image, {
    int fileHeight,
    int fileWidth,
  }) async {
    var data = await _httpHelper.multipartRequest(
      "sublocation/add",
      body: {
        "title": title,
        "filewidth": fileWidth.toString(),
        "fileheight": fileHeight.toString(),
      },
      file: {
        "field": "files",
        "path": image.path,
      },
      requestParams: {
        "locationId": id.toString(),
      },
    );

    return SubLocation.fromMap(data);
  }
}

==> 0.2.0.tar.gz: lib/models/location.dart <==
part of navigine_api;

class Location {
  int id = 0, sort = 0, userRoleId = 0, userPermissionId = 0;
  String title;
  String description = "";
  bool isPublic = false, activeDragDrop = false, state = false;
  List<SubLocation> subLocations;

  static Location fromMap(var data) {
    return Location()
      ..id = data["id"]
      ..sort = data["sort"]
      // ..state = data["state"]
      ..userRoleId = data["userRoleId"]
      ..userPermissionId = data["userPermissionId"]
      ..title = data["title"]
      ..description = data["description"]
      ..isPublic = data["is_public"]
      ..activeDragDrop = data["active_drag_drop"]
      ..subLocations = (data["subLocations"] ?? [])
          .map<SubLocation>((l) => SubLocation.fromMap(l))
          .toList();
  }

  SubLocation getSubLocationDetail(int id) {
    return subLocations.firstWhere((sl) => sl.id == id);
  }

  /// Returns version of the updated map archive
  Future<int> saveLocation() async {
    var resp = await _httpHelper.getRequest("/versions/save", body: {
      "format": "json",
      "locationId": id.toString(),
    });
    return resp["version"]["version"];
  }

  Future addNewSubLocation(
    String title,
    File image, {
    int fileHeight,
    int fileWidth,
  }) async {
    var data = await _httpHelper.multipartRequest(
      "sublocations/add",
      body: {
        "title": title,
        "filewidth": fileWidth.toString(),
        "fileheight": fileHeight.toString(),
      },
      file: {
        "field": "files",
        "path": image.path,
      },
      requestParams: {
        "locationId": id.toString(),
      },
    );

    return SubLocation.fromMap(data);
  }
}
